"""
Open Edison Source Package.

Note: Avoid importing heavy submodules at package import time to keep
packaging/import of light utilities (e.g., mcp_importer) side‑effect free.
"""

__all__: list[str] = []
